==> jc-1.4.0.tar.gz: soot/jimple/toolkits/typing/ClassHierarchy__24ConstructorChooser.h <==
// class soot.jimple.toolkits.typing.ClassHierarchy$ConstructorChooser

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch
// @dep_class 2c435a34953076d9 soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser

// header file dependencies
// @dep_header soot_TypeSwitch

#include "soot/TypeSwitch.h"

#ifndef _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser_H_
#define _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_ArrayType$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object;
struct _jc_soot_jimple_toolkits_typing_TypeNode$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object;

typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$caseArrayType$d56bd9480f72ecfb(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_ArrayType$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$caseRefType$c4ae2c5ccda235b9(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_RefType$object *);
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$defaultCase$de008c64d36e8465(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_Type$object *);
extern struct _jc_soot_jimple_toolkits_typing_TypeNode$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$typeNode$0706d9dd860f8324(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, jint, struct _jc_soot_Type$object *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$caseArrayType$d56bd9480f72ecfb;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$caseRefType$c4ae2c5ccda235b9;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$defaultCase$de008c64d36e8465;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$typeNode$0706d9dd860f8324;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods {
	void	(*caseArrayType$d56bd9480f72ecfb)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_ArrayType$object *);
	void	(*caseRefType$c4ae2c5ccda235b9)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_RefType$object *);
	void	(*defaultCase$de008c64d36e8465)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_Type$object *);
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*(*typeNode$0706d9dd860f8324)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, jint, struct _jc_soot_Type$object *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods	soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs {
	struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object	*hierarchy;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*result;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs {
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs	soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs	soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object {
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/typing/ClassHierarchy__24ConstructorChooser.h <==
// class soot.jimple.toolkits.typing.ClassHierarchy$ConstructorChooser

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 12e2cc897947b1d6 soot_TypeSwitch
// @dep_class 2c435a34953076d9 soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser

// header file dependencies
// @dep_header soot_TypeSwitch

#include "soot/TypeSwitch.h"

#ifndef _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser_H_
#define _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_ArrayType$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object;
struct _jc_soot_jimple_toolkits_typing_TypeNode$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object;

typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$caseArrayType$d56bd9480f72ecfb(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_ArrayType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$caseRefType$c4ae2c5ccda235b9(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$defaultCase$de008c64d36e8465(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_typing_TypeNode$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method$typeNode$0706d9dd860f8324(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, jint, struct _jc_soot_Type$object *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$caseArrayType$d56bd9480f72ecfb;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$caseRefType$c4ae2c5ccda235b9;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$defaultCase$de008c64d36e8465;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$method_info$typeNode$0706d9dd860f8324;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods {
	void	(*caseArrayType$d56bd9480f72ecfb)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_ArrayType$object *) _JC_JCNI_ATTR;
	void	(*caseRefType$c4ae2c5ccda235b9)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
	void	(*defaultCase$de008c64d36e8465)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*(*typeNode$0706d9dd860f8324)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object *, jint, struct _jc_soot_Type$object *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_TypeSwitch$vmethods	soot_TypeSwitch;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vmethods	soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs {
	struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object	*hierarchy;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*result;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs {
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_refs	soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser;
    _jc_soot_TypeSwitch$sub_refs	soot_TypeSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_TypeSwitch$sub_nonrefs	soot_TypeSwitch;
    _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$sub_nonrefs	soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object {
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$vtype _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser_H_ */
